Improve this doc

# Error: $injector:modulerr
Module Error

    Failed to instantiate module {0} due to:
    {1}

## Description

This error occurs when a module fails to load due to some exception. The error message above should provide additional context.

In AngularJS `1.2.0` and later, `ngRoute` has been moved to its own module. If you are getting this error after upgrading to `1.2.x`, be sure that you've installed `ngRoute`.